@@ -1,4 +1,5 @@
 import asyncio
+import contextvars
 import dataclasses
 import itertools
 import logging
@@ -15,6 +16,7 @@ from acron.job import Job
 __all__ = [
     "Scheduler",
     "ScheduledJob",
+    "job_context",
 ]
 
 
@@ -44,8 +46,9 @@ class ScheduledJob:
     id: str = dataclasses.field(default_factory=lambda: str(uuid.uuid4()))
 
     async def run(self) -> None:
-        start = time.monotonic()
         log.debug("[scheduler id=%s] Running scheduled job %s", self.id, self.job.name)
+        start = time.monotonic()
+        job_context.set(self)
         try:
             # mypy gets confused because we are calling a function but
             # it looks like we are calling a method.
@@ -60,6 +63,11 @@ class ScheduledJob:
             )
 
 
+job_context: contextvars.ContextVar[ScheduledJob] = contextvars.ContextVar(
+    "job_context"
+)
+
+
 ScheduledJobHandle = Tuple[ScheduledJob, asyncio.TimerHandle]
 
 
@@ -170,7 +178,11 @@ def show_scheduled_jobs_info(
 
 class Scheduler:
     def __init__(
-        self, tz: Optional[timezone] = None, *, now: Optional[datetime] = None
+        self,
+        tz: Optional[timezone] = None,
+        *,
+        now: Optional[datetime] = None,
+        dry_run: bool = False
     ) -> None:
         self._jobs_queue: "Optional[asyncio.Queue[Set[Job]]]" = None
         self._tz = tz if tz is not None else timezone.utc
@@ -183,7 +195,7 @@ class Scheduler:
         self._last_job_time: Optional[float] = None
         self._last_scheduled_info = now or datetime.now()
         self._last_scheduled_delay = 3600
-        self._dry_run = False
+        self._dry_run = dry_run
 
     def process_jobs_update(
         self, new_jobs: Set[Job], *, now: Optional[datetime] = None
